/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03819
 |         NATIONAL SURVEY OF SUBSTANCE ABUSE TREATMENT SERVICES
 |                            (N-SSATS), 2002
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03819-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE mode      1='(1) Phone' 2='(2) Mail' 9='(9) Web' ;
  VALUE stfips    1='(01) ALABAMA' 2='(02) ALASKA' 4='(04) ARIZONA'
                  5='(05) ARKANSAS' 6='(06) CALIFORNIA' 8='(08) COLORADO'
                  9='(09) CONNECTICUT' 10='(10) DELAWARE'
                  11='(11) DIST OF COLUMBIA' 12='(12) FLORIDA'
                  13='(13) GEORGIA' 15='(15) HAWAII' 16='(16) IDAHO'
                  17='(17) ILLINOIS' 18='(18) INDIANA' 19='(19) IOWA'
                  20='(20) KANSAS' 21='(21) KENTUCKY' 22='(22) LOUISIANA'
                  23='(23) MAINE' 24='(24) MARYLAND' 25='(25) MASSACHUSETTS'
                  26='(26) MICHIGAN' 27='(27) MINNESOTA'
                  28='(28) MISSISSIPPI' 29='(29) MISSOURI' 30='(30) MONTANA'
                  31='(31) NEBRASKA' 32='(32) NEVADA' 33='(33) NEW HAMPSHIRE'
                  34='(34) NEW JERSEY' 35='(35) NEW MEXICO'
                  36='(36) NEW YORK' 37='(37) NORTH CAROLINA'
                  38='(38) NORTH DAKOTA' 39='(39) OHIO' 40='(40) OKLAHOMA'
                  41='(41) OREGON' 42='(42) PENNSYLVANIA'
                  44='(44) RHODE ISLAND' 45='(45) SOUTH CAROLINA'
                  46='(46) SOUTH DAKOTA' 47='(47) TENNESSEE' 48='(48) TEXAS'
                  49='(49) UTAH' 50='(50) VERMONT' 51='(51) VIRGINIA'
                  53='(53) WASHINGTON' 54='(54) WEST VIRGINIA'
                  55='(55) WISCONSIN' 56='(56) WYOMING'
                  60='(60) AMERICAN SAMOA' 64='(64) FED MICRONESIA'
                  66='(66) GUAM' 70='(70) PALAU' 72='(72) PUERTO RICO'
                  78='(78) VIRGIN ISLANDS' ;
  VALUE region    0='(0) US Jurisdiction/Territory' 1='(1) Northeast'
                  2='(2) Midwest' 3='(3) South' 4='(4) West' ;
  VALUE division  0='(0) US Jurisdiction/Territory' 1='(1) New England'
                  2='(2) Mid-Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central'
                  8='(8) Mountain' 9='(9) Pacific' ;
  VALUE treatmt   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE detox     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ownershp  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Private for-profit organization'
                  2='(2) Private non-profit organization'
                  3='(3) State government'
                  4='(4) Local, county, or community government'
                  5='(5) Tribal government' 6='(6) Federal government' ;
  VALUE fedown    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Department of Veterans Affairs'
                  2='(2) Department of Defense' 3='(3) Indian Health Service'
                  4='(4) Other' ;
  VALUE loc15fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE relig     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE hospital  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE locs      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) General hospital (including VA)'
                  2='(2) Psychiatric hospital'
                  3='(3) Other specialty hospital' ;
  VALUE focus     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Substance abuse treatment services'
                  2='(2) Mental health services' 3='(3) General health care'
                  4='(4) Mix of mental health and substance abuse'
                  5='(5) Other' ;
  VALUE hotyn     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc2fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc5fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc6fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc8fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc27ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc70ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc71ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc10ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc11ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc13ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc14ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc15ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc16ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc36ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc37ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc38ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc39ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc40ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc49ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc50ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc52ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc24ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc55ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc59ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc48ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE otp       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE otptype   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Maintenance program' 2='(2) Detoxification program'
                  3='(3) Both' ;
  VALUE otpall    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE dui_dwi   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE onlydui   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc61ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE signlang  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang2fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang3fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang5fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang6fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang7fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang8fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang9fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang10ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang11ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang12ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang13ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang14ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang15ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang16ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang17ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE lang18ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc30ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc31ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc32ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc62ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc63ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc33ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc34ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc64ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE srvc35ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctype4ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctypehif  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctypeh0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE hospbed   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE ctype7ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctypercf  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctyper0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE resbed    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE ctype1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctype6ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctypeml   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctype3ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctype2ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ctypeop   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk8f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk5f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk2f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk3f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE revchk2a  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE earmark   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE feescale  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE payasst   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE writarra  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE licensed  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE licenmh   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE licenph   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE licenhos  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE jcaho     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE carf      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE ncqa      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE coa       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE othstate  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE adminlnk  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE othfac2f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE othfac1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE othfac3f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE type4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE t_cli1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli2ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clihi   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE h_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE himetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE hilamnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE type7fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE t_cli3ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli4ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clirc   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE r_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE rcmetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE rclamnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE type1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE t_cli7ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_climl   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli5ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli6ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli8ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cliop   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE o_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE opmetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE oplamnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE b_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE a_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE d_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE totadmis  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE faccli    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Only this facility'
                  2='(2) This facility plus others' ;
  VALUE facnum    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE acthi     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 1='(1) Actual'
                  2='(2) Estimate' ;
  VALUE actres    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 1='(1) Actual'
                  2='(2) Estimate' ;
  VALUE actop     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 1='(1) Actual'
                  2='(2) Estimate' ;
  VALUE totadest  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 1='(1) Actual'
                  2='(2) Estimate' ;
  VALUE loc5ffff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes, at this location'
                  2='(2) Yes, at another location'
                  3='(3) Yes, at this and other locations' ;
  VALUE internet  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE hasweb    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' 0='(0) No'
                  1='(1) Yes' ;
  VALUE rptlvl    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Reporting for self'
                  2='(2) Reporting for self and others'
                  3='(3) Client counts reported by another facility' ;
  VALUE t_cli9ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clijuv  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_climet  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -3='(-3) Invalid Response'
                  -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE ownrspfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE fedownfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE otpfl     0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE ctypehfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE ctyperfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE ctypeofl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE ctypemlf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE linksfl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli1fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli2fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_clihif  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE himtnmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE hilmnmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli3fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli4fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_clircf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE rcmtnmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE rclmnmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli7fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_climlf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli5fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli6fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cli8fl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cliopf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE opmtnmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE oplmnmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE b_pctfl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE a_pctfl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE d_pctfl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE totadmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=507;
INPUT
        CASEID 1-5              MODE 6                  STFIPS 7-8
        REGION 9                DIVISION 10             TREATMT 11-13
        DETOX 14-16             OWNERSHP 17-19          FEDOWN 20-22
        LOC15 23-25             RELIG 26-28             HOSPITAL 29-31
        LOCS 32-34              FOCUS 35-37             HOTYN 38-40
        SRVC1 41-43             SRVC2 44-46             SRVC4 47-49
        SRVC5 50-52             SRVC6 53-55             SRVC8 56-58
        SRVC27 59-61            SRVC70 62-64            SRVC71 65-67
        SRVC10 68-70            SRVC11 71-73            SRVC13 74-76
        SRVC14 77-79            SRVC15 80-82            SRVC16 83-85
        SRVC36 86-88            SRVC37 89-91            SRVC38 92-94
        SRVC39 95-97            SRVC40 98-100           SRVC49 101-103
        SRVC50 104-106          SRVC52 107-109          SRVC24 110-112
        SRVC55 113-115          SRVC59 116-118          SRVC48 119-121
        OTP 122-124             OTPTYPE 125-127         OTPALL 128-130
        DUI_DWI 131-133         ONLYDUI 134-136         SRVC61 137-139
        SIGNLANG 140-142        LANG 143-145            LANG1 146-148
        LANG2 149-151           LANG3 152-154           LANG4 155-157
        LANG5 158-160           LANG6 161-163           LANG7 164-166
        LANG8 167-169           LANG9 170-172           LANG10 173-175
        LANG11 176-178          LANG12 179-181          LANG13 182-184
        LANG14 185-187          LANG15 188-190          LANG16 191-193
        LANG17 194-196          LANG18 197-199          SRVC30 200-202
        SRVC31 203-205          SRVC32 206-208          SRVC62 209-211
        SRVC63 212-214          SRVC33 215-217          SRVC34 218-220
        SRVC64 221-223          SRVC35 224-226          CTYPE4 227-229
        CTYPEHI1 230-232        CTYPEHI2 233-235        HOSPBED 236-238
        CTYPE7 239-241          CTYPERC1 242-244        CTYPERC2 245-247
        RESBED 248-250          CTYPE1 251-253          CTYPE6 254-256
        CTYPEML 257-259         CTYPE3 260-262          CTYPE2 263-265
        CTYPEOP 266-268         REVCHK1 269-271         REVCHK8 272-274
        REVCHK5 275-277         REVCHK10 278-280        REVCHK15 281-283
        REVCHK2 284-286         REVCHK2A 287-289        EARMARK 290-292
        FEESCALE 293-295        PAYASST 296-298         WRITARRA 299-301
        LICENSED 302-304        LICENMH 305-307         LICENPH 308-310
        LICENHOS 311-313        JCAHO 314-316           CARF 317-319
        NCQA 320-322            COA 323-325             OTHSTATE 326-328
        ADMINLNK 329-331        OTHFAC2 332-334         OTHFAC1 335-337
        OTHFAC3 338-340         TYPE4 341-343           T_CLI1 344-346
        T_CLI2 347-349          T_CLIHI 350-352         H_AGE1 353-355
        HIMETNUM 356-358        HILAMNUM 359-361        TYPE7 362-364
        T_CLI3 365-367          T_CLI4 368-370          T_CLIRC 371-373
        R_AGE1 374-376          RCMETNUM 377-379        RCLAMNUM 380-382
        TYPE1 383-385           T_CLI7 386-389          T_CLIML 390-393
        T_CLI5 394-397          T_CLI6 398-401          T_CLI8 402-405
        T_CLIOP 406-409         O_AGE1 410-413          OPMETNUM 414-417
        OPLAMNUM 418-421        B_PCT 422-424           A_PCT 425-427
        D_PCT 428-430           TOTADMIS 431-435        FACCLI 436-438
        FACNUM 439-441          ACTHI 442-444           ACTRES 445-447
        ACTOP 448-450           TOTADEST 451-453        LOC5 454-456
        INTERNET 457-459        HASWEB 460-462          RPTLVL 463-465
        T_CLI9 466-469          T_CLIJUV 470-473        T_CLIMET 474-477
        OWNRSPFL 478            FEDOWNFL 479            OTPFL 480
        CTYPEHFL 481            CTYPERFL 482            CTYPEOFL 483
        CTYPEMLF 484            LINKSFL 485             T_CLI1FL 486
        T_CLI2FL 487            T_CLIHIF 488            HIMTNMFL 489
        HILMNMFL 490            T_CLI3FL 491            T_CLI4FL 492
        T_CLIRCF 493            RCMTNMFL 494            RCLMNMFL 495
        T_CLI7FL 496            T_CLIMLF 497            T_CLI5FL 498
        T_CLI6FL 499            T_CLI8FL 500            T_CLIOPF 501
        OPMTNMFL 502            OPLMNMFL 503            B_PCTFL 504
        A_PCTFL 505             D_PCTFL 506             TOTADMFL 507
        ;


* SAS LABEL STATEMENT;

LABEL 
   CASEID  = 'Case Identification Number' 
   MODE    = 'Control: Completes 1=phone 2=mail 9=web' 
   STFIPS  = 'Census State FIPS codes label' 
   REGION  = 'Added: Census Region' 
   DIVISION= 'Added: Census Division' 
   TREATMT = 'Q1. Offered Substance Abuse Tx Svcs 3/29/02' 
   DETOX   = 'Q1a. Offered Detox Svcs 3/29/02' 
   OWNERSHP= 'Q2. Operated by' 
   FEDOWN  = 'Q2a. Federal Govt Agency' 
   LOC15   = 'Q3. Private Solo Practice' 
   RELIG   = 'Q4. Affiliated w/Religious Org' 
   HOSPITAL= 'Q6. Located In/Operated by Hospital' 
   LOCS    = 'Q6a. Hospital Type' 
   FOCUS   = 'Q7. Primary Focus SA/MH/Genl Health/Mix' 
   HOTYN   = 'Q8. SA Hotline' 
   SRVC1   = 'Q10. Assessment: Substance Abuse' 
   SRVC2   = 'Q10. Assessment: Mental Health' 
   SRVC4   = 'Q10. Therapy: Family Counseling' 
   SRVC5   = 'Q10. Therapy: Group' 
   SRVC6   = 'Q10. Therapy: Individual' 
   SRVC8   = 'Q10. Therapy: Relapse Prevention' 
   SRVC27  = 'Q10. Therapy: Aftercare Counseling' 
   SRVC70  = 'Q10. Pharmacotherapies: Antabuse' 
   SRVC71  = 'Q10. Pharmacotherapies: Naltrexone' 
   SRVC10  = 'Q10. Testing: Blood/Alcohol' 
   SRVC11  = 'Q10. Testing: Drug/Alcohol Urine Screen' 
   SRVC13  = 'Q10. Testing: Hepatitis' 
   SRVC14  = 'Q10. Testing: HIV' 
   SRVC15  = 'Q10. Testing: STD' 
   SRVC16  = 'Q10. Testing: TB Screen' 
   SRVC36  = 'Q10. Transitional: Assistance w/Social Svcs' 
   SRVC37  = 'Q10. Transitional: Discharge Plan' 
   SRVC38  = 'Q10. Transitional: Employment' 
   SRVC39  = 'Q10. Transitional: Housing' 
   SRVC40  = 'Q10. Transitional: Referral to Transitional Svcs' 
   SRVC49  = 'Q10. Other Svcs: Case Management' 
   SRVC50  = 'Q10. Other Svcs: Child Svcs' 
   SRVC52  = 'Q10. Other Svcs: Domestic Violence' 
   SRVC24  = 'Q10. Other Svcs: HIV/AIDS Educ' 
   SRVC55  = 'Q10. Other Svcs: Outcome Follow-Up' 
   SRVC59  = 'Q10. Other Svcs: Transportation Assistance' 
   SRVC48  = 'Q10. Other Svcs: Acupuncture' 
   OTP     = 'Q11. Operates Opioid Treatment Program' 
   OTPTYPE = 'Q11a. OTP is Maint/Detox/Both' 
   OTPALL  = 'Q11b. Are All SA Clients in OTP?' 
   DUI_DWI = 'Q12. Pgm for DUI/DWI Offenders' 
   ONLYDUI = 'Q12A. Are All SA Tx Clients DUI/DWI?' 
   SRVC61  = 'Q13. Pgm/Grp for Non-DUI/DWI Criminal Justice Clients' 
   SIGNLANG= 'Q14. SA Tx in Sign Language' 
   LANG    = 'Q15. SA Tx in Language Other Than English' 
   LANG1   = 'Q15a. SA Tx in Hopi' 
   LANG2   = 'Q15a. SA Tx in Lakota' 
   LANG3   = 'Q15a. SA Tx in Navajo' 
   LANG4   = 'Q15a. SA Tx in Yupik' 
   LANG5   = 'Tx in Other American Indian/Alaska Native' 
   LANG6   = 'Q15a. SA Tx in Arabic' 
   LANG7   = 'Q15a. SA Tx in Chinese' 
   LANG8   = 'Q15a. SA Tx in Creole' 
   LANG9   = 'Q15a. SA Tx in French' 
   LANG10  = 'Q15a. SA Tx in German' 
   LANG11  = 'Q15a. SA Tx in Hmong' 
   LANG12  = 'Q15a. SA Tx in Korean' 
   LANG13  = 'Q15a. SA Tx in Polish' 
   LANG14  = 'Q15a. SA Tx in Portuguese' 
   LANG15  = 'Q15a. SA Tx in Russian' 
   LANG16  = 'Q15a. SA Tx in Spanish' 
   LANG17  = 'Q15a. SA Tx in Vietnamese' 
   LANG18  = 'Q15a. SA Tx in Other Language' 
   SRVC30  = 'Q16. Pgm/Grp for Adolescents' 
   SRVC31  = 'Q16. Pgm/Grp for Dually-Diagnosed' 
   SRVC32  = 'Q16. Pgm/Grp for Persons with HIV/AIDS' 
   SRVC62  = 'Q16. Pgm/Grp for Gays/Lesbians' 
   SRVC63  = 'Q16. Pgm/Grp for Seniors/Older Adults' 
   SRVC33  = 'Q16. Pgm/Grp for Pregnant/Postpartum Women' 
   SRVC34  = 'Q16. Pgm/Grp for Women Only' 
   SRVC64  = 'Q16. Pgm/Grp for Men Only' 
   SRVC35  = 'Q16. Pgm/Grp for Other Groups' 
   CTYPE4  = 'Q17. Hospital Inpatient SA Svcs Offered' 
   CTYPEHI1= 'Q17a. Hospital Inpatient Svcs - Detox' 
   CTYPEHI2= 'Q17a. Hospital Inpatient Svcs - Rehab' 
   HOSPBED = 'Q17b. Beds Designated for SA Tx - Hospital Inpatient' 
   CTYPE7  = 'Q18. Residential SA Svcs Offered' 
   CTYPERC1= 'Q18a. Residential Svcs - Detox' 
   CTYPERC2= 'Q18a. Residential Svcs - Rehab' 
   RESBED  = 'Q18b. Beds Designated for SA Tx - Residential' 
   CTYPE1  = 'Q19. Outpatient SA Svcs Offered' 
   CTYPE6  = 'Q19a. Outpatient Svcs - Detox' 
   CTYPEML = 'Q19a. Outpatient Svcs - Methadone/LAAM Maint' 
   CTYPE3  = 'Q19a. Outpatient Svcs - Regular' 
   CTYPE2  = 'Q19a. Outpatient- Intensive' 
   CTYPEOP = 'Q19a. Outpatient Svcs - Day Tx/Partial Hosp' 
   REVCHK1 = 'Q20. Cash or Self-Payment for SA Tx' 
   REVCHK8 = 'Q20. Medicare Payments for SA Tx' 
   REVCHK5 = 'Q20. Medicaid Payments for SA Tx' 
   REVCHK10= 'Q20. State-Financed Health Ins' 
   REVCHK15= 'Q20. Federal Military Ins for SA Tx' 
   REVCHK2 = 'Q20. Private Health Ins for SA Tx' 
   REVCHK2A= 'Q20. Other Payments for SA Tx' 
   EARMARK = 'Q21. Rcvs Fed, State, County, Local Funds for SA Tx' 
   FEESCALE= 'Q22. Uses  Sliding Fee Scale' 
   PAYASST = 'Q23. Offers Other Payment Assistance' 
   WRITARRA= 'Q23. Agreements/Contracts w/Managed Care Orgs' 
   LICENSED= 'Q24. Licen/Cert by State SA Agency' 
   LICENMH = 'Q24. Licen/Cert by State Mental Health Dept' 
   LICENPH = 'Q24. Licen/Cert by State Public Health Dept' 
   LICENHOS= 'Q24. Licen/Cert by Hospital Licensing Authority' 
   JCAHO   = 'Q24. Accred by JCAHO' 
   CARF    = 'Q24. Accred by CARF' 
   NCQA    = 'Q24. Accred by NCQA' 
   COA     = 'Q24. Accred by COA' 
   OTHSTATE= 'Q24. Licen/Cert by Other State Agency' 
   ADMINLNK= 'Q25. Part of Org with Multiple Facilities/Sites' 
   OTHFAC2 = 'Q25a. Client Counts for This Facility Only' 
   OTHFAC1 = 'Q25a. Client Counts for This Facility & Others in Org' 
   OTHFAC3 = 'Q25a. Client Counts Reported by Another Facility' 
   TYPE4   = 'Q26. Hospital Inpatient SA Clients 3/29/02' 
   T_CLI1  = 'Q26a. Hospital Inpatient Clients - Detox' 
   T_CLI2  = 'Q26a. Hospital Inpatient Clients - Rehab' 
   T_CLIHI = 'Q26a. Hospital Inpatient Clients - Total' 
   H_AGE1  = 'Q26b. Hospital Inpatient Clients Under Age 18' 
   HIMETNUM= 'Q26c. Hospital Inpatient Clients - Methadone Detox/Maint' 
   HILAMNUM= 'Q26c. Hospital Inpatient Clients - LAAM Detox/Maint' 
   TYPE7   = 'Q27. Residential SA Clients 3/29/02' 
   T_CLI3  = 'Q27a. Residential Clients - Detox' 
   T_CLI4  = 'Q27a. Residential Clients - Rehab' 
   T_CLIRC = 'Q27a. Residential Clients - Total' 
   R_AGE1  = 'Q27b. Residential Clients Under Age 18' 
   RCMETNUM= 'Q27c. Residential Clients - Methadone Detox/Maint' 
   RCLAMNUM= 'Q27c. Residential - LAAM Detox/Maint' 
   TYPE1   = 'Q28. Outpatient SA Clients 3/29/02' 
   T_CLI7  = 'Q28a. Outpatient Clients - Detox' 
   T_CLIML = 'Q28a. Outpatient Clients - Methadone/LAAM Maint' 
   T_CLI5  = 'Q28a. Outpatient Clients - Regular Outpatient' 
   T_CLI6  = 'Q28a. Outpatient Clients - Intensive Outpatient' 
   T_CLI8  = 'Q28a. Outpatient Clients - Day Tx/Partial Hosp' 
   T_CLIOP = 'Q28a. Outpatient Clients - Total' 
   O_AGE1  = 'Q28b. Outpatient Clients Under Age 18' 
   OPMETNUM= 'Q28c. Outpatient Clients - Methadone Detox/Maint' 
   OPLAMNUM= 'Q28c. Outpatient Clients - LAAM Detox/Maint' 
   B_PCT   = 'Q29. Percent Treated for Alcohol & Drug Abuse' 
   A_PCT   = 'Q29. Percent Treated for Alcohol Abuse Only' 
   D_PCT   = 'Q29. Percent Treated for Drug Abuse Only' 
   TOTADMIS= 'Q30. Total Annual Admissions for SA Tx' 
   FACCLI  = 'Q31. Other Facilities Included in Client Counts' 
   FACNUM  = 'Q31. # of Other Facilities in Client Counts' 
   ACTHI   = 'Q32. Actual/Est Hospital Inpatient Client Count' 
   ACTRES  = 'Q32. Actual/Est Residential Client Count' 
   ACTOP   = 'Q32. Actual/Est Outpatient Client Count' 
   TOTADEST= 'Q32. Actual/Est Annual Admissions' 
   LOC5    = 'Q33. Operates Halfway House' 
   INTERNET= 'Q34. Has Internet Access' 
   HASWEB  = 'Q35. Has Web Site' 
   RPTLVL  = 'Added: Reporting for Self, Self & Others, No Counts' 
   T_CLI9  = 'Added: Total Clients 3/29/02' 
   T_CLIJUV= 'Added: Total Clients Under Age 18 3/29/02' 
   T_CLIMET= 'Added: Total Methadone/LAAM Detox/Maint Clients 3/29/02' 
   OWNRSPFL= 'Flag: Q2 Operated by' 
   FEDOWNFL= 'Flag: Q2a Federal Govt Agency' 
   OTPFL   = 'Flag: Q11 Q11a Q11b OTP Logic' 
   CTYPEHFL= 'Flag: Q17 Q17a Q26 Q26a Hospital Svc/Client Counts Logic' 
   CTYPERFL= 'Flag: Q18 Q18a Q27 Q27a Residential Svc/Client Counts Logic' 
   CTYPEOFL= 'Flag: Q19 Q19a Q28 Q28a Outpatient Svc/Client Counts Logic' 
   CTYPEMLF= 'Flag: Q19a Q26a  Outpatient Methadone Svc/Client Counts Logic' 
   LINKSFL = 'Flag: Q25 Q25a Q31 Administrative Links Logic' 
   T_CLI1FL= 'Flag: Q26a Hospital Inpatient Clients - Detox' 
   T_CLI2FL= 'Flag: Q26a Hospital Inpatient Clients - Rehab' 
   T_CLIHIF= 'Flag: Q26a Hospital Inpatient Clients - Total' 
   HIMTNMFL= 'Flag: Q26c Hospital Inpatient Clients - Methadone Detox/Maint' 
   HILMNMFL= 'Flag: Q26c Hospital Inpatient Clients - LAAM Detox/Maint' 
   T_CLI3FL= 'Flag: Q27a Residential Clients - Detox' 
   T_CLI4FL= 'Flag: Q27a Residential Clients - Rehab' 
   T_CLIRCF= 'Flag: Q27a Residential Clients - Total' 
   RCMTNMFL= 'Flag: Q27c Residential Clients - Methadone Detox/Maint' 
   RCLMNMFL= 'Flag: Q27c Residential - LAAM Detox/Maint' 
   T_CLI7FL= 'Flag: Q28a Outpatient Clients - Detox' 
   T_CLIMLF= 'Flag: Q28a Outpatient Clients - Meth/LAAM Maint' 
   T_CLI5FL= 'Flag: Q28a Outpatient Clients - Regular Outpatient' 
   T_CLI6FL= 'Flag: Q28a Outpatient Clients - Intensive Outpatient' 
   T_CLI8FL= 'Flag: Q28a Outpatient Clients - Day Tx/Partial Hosp' 
   T_CLIOPF= 'Flag: Q28a Outpatient Clients - Total' 
   OPMTNMFL= 'Flag: Q28c Outpatient Clients - Methadone Detox/Maint' 
   OPLMNMFL= 'Flag: Q28c Outpatient Clients - LAAM Detox/Maint' 
   B_PCTFL = 'Flag: Q29 Percent Treated for Alcohol & Drug Abuse' 
   A_PCTFL = 'Flag: Q29 Percent Treated for Alcohol Abuse Only' 
   D_PCTFL = 'Flag: Q29 Percent Treated for Drug Abuse Only' 
   TOTADMFL= 'Flag: Q30 Total Annual Admissions for SA Tx' 
        ; 


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (TREATMT <= -1) THEN TREATMT = .;
   IF (DETOX <= -1) THEN DETOX = .;
   IF (OWNERSHP <= -1) THEN OWNERSHP = .;
   IF (FEDOWN <= -1) THEN FEDOWN = .;
   IF (LOC15 <= -1) THEN LOC15 = .;
   IF (RELIG <= -1) THEN RELIG = .;
   IF (HOSPITAL <= -1) THEN HOSPITAL = .;
   IF (LOCS <= -1) THEN LOCS = .;
   IF (FOCUS <= -1) THEN FOCUS = .;
   IF (HOTYN <= -1) THEN HOTYN = .;
   IF (SRVC1 <= -1) THEN SRVC1 = .;
   IF (SRVC2 <= -1) THEN SRVC2 = .;
   IF (SRVC4 <= -1) THEN SRVC4 = .;
   IF (SRVC5 <= -1) THEN SRVC5 = .;
   IF (SRVC6 <= -1) THEN SRVC6 = .;
   IF (SRVC8 <= -1) THEN SRVC8 = .;
   IF (SRVC27 <= -1) THEN SRVC27 = .;
   IF (SRVC70 <= -1) THEN SRVC70 = .;
   IF (SRVC71 <= -1) THEN SRVC71 = .;
   IF (SRVC10 <= -1) THEN SRVC10 = .;
   IF (SRVC11 <= -1) THEN SRVC11 = .;
   IF (SRVC13 <= -1) THEN SRVC13 = .;
   IF (SRVC14 <= -1) THEN SRVC14 = .;
   IF (SRVC15 <= -1) THEN SRVC15 = .;
   IF (SRVC16 <= -1) THEN SRVC16 = .;
   IF (SRVC36 <= -1) THEN SRVC36 = .;
   IF (SRVC37 <= -1) THEN SRVC37 = .;
   IF (SRVC38 <= -1) THEN SRVC38 = .;
   IF (SRVC39 <= -1) THEN SRVC39 = .;
   IF (SRVC40 <= -1) THEN SRVC40 = .;
   IF (SRVC49 <= -1) THEN SRVC49 = .;
   IF (SRVC50 <= -1) THEN SRVC50 = .;
   IF (SRVC52 <= -1) THEN SRVC52 = .;
   IF (SRVC24 <= -1) THEN SRVC24 = .;
   IF (SRVC55 <= -1) THEN SRVC55 = .;
   IF (SRVC59 <= -1) THEN SRVC59 = .;
   IF (SRVC48 <= -1) THEN SRVC48 = .;
   IF (OTP <= -1) THEN OTP = .;
   IF (OTPTYPE <= -1) THEN OTPTYPE = .;
   IF (OTPALL <= -1) THEN OTPALL = .;
   IF (DUI_DWI <= -1) THEN DUI_DWI = .;
   IF (ONLYDUI <= -1) THEN ONLYDUI = .;
   IF (SRVC61 <= -1) THEN SRVC61 = .;
   IF (SIGNLANG <= -1) THEN SIGNLANG = .;
   IF (LANG <= -1) THEN LANG = .;
   IF (LANG1 <= -1) THEN LANG1 = .;
   IF (LANG2 <= -1) THEN LANG2 = .;
   IF (LANG3 <= -1) THEN LANG3 = .;
   IF (LANG4 <= -1) THEN LANG4 = .;
   IF (LANG5 <= -1) THEN LANG5 = .;
   IF (LANG6 <= -1) THEN LANG6 = .;
   IF (LANG7 <= -1) THEN LANG7 = .;
   IF (LANG8 <= -1) THEN LANG8 = .;
   IF (LANG9 <= -1) THEN LANG9 = .;
   IF (LANG10 <= -1) THEN LANG10 = .;
   IF (LANG11 <= -1) THEN LANG11 = .;
   IF (LANG12 <= -1) THEN LANG12 = .;
   IF (LANG13 <= -1) THEN LANG13 = .;
   IF (LANG14 <= -1) THEN LANG14 = .;
   IF (LANG15 <= -1) THEN LANG15 = .;
   IF (LANG16 <= -1) THEN LANG16 = .;
   IF (LANG17 <= -1) THEN LANG17 = .;
   IF (LANG18 <= -1) THEN LANG18 = .;
   IF (SRVC30 <= -1) THEN SRVC30 = .;
   IF (SRVC31 <= -1) THEN SRVC31 = .;
   IF (SRVC32 <= -1) THEN SRVC32 = .;
   IF (SRVC62 <= -1) THEN SRVC62 = .;
   IF (SRVC63 <= -1) THEN SRVC63 = .;
   IF (SRVC33 <= -1) THEN SRVC33 = .;
   IF (SRVC34 <= -1) THEN SRVC34 = .;
   IF (SRVC64 <= -1) THEN SRVC64 = .;
   IF (SRVC35 <= -1) THEN SRVC35 = .;
   IF (CTYPE4 <= -1) THEN CTYPE4 = .;
   IF (CTYPEHI1 <= -1) THEN CTYPEHI1 = .;
   IF (CTYPEHI2 <= -1) THEN CTYPEHI2 = .;
   IF (HOSPBED <= -1) THEN HOSPBED = .;
   IF (CTYPE7 <= -1) THEN CTYPE7 = .;
   IF (CTYPERC1 <= -1) THEN CTYPERC1 = .;
   IF (CTYPERC2 <= -1) THEN CTYPERC2 = .;
   IF (RESBED <= -1) THEN RESBED = .;
   IF (CTYPE1 <= -1) THEN CTYPE1 = .;
   IF (CTYPE6 <= -1) THEN CTYPE6 = .;
   IF (CTYPEML <= -1) THEN CTYPEML = .;
   IF (CTYPE3 <= -1) THEN CTYPE3 = .;
   IF (CTYPE2 <= -1) THEN CTYPE2 = .;
   IF (CTYPEOP <= -1) THEN CTYPEOP = .;
   IF (REVCHK1 <= -1) THEN REVCHK1 = .;
   IF (REVCHK8 <= -1) THEN REVCHK8 = .;
   IF (REVCHK5 <= -1) THEN REVCHK5 = .;
   IF (REVCHK10 <= -1) THEN REVCHK10 = .;
   IF (REVCHK15 <= -1) THEN REVCHK15 = .;
   IF (REVCHK2 <= -1) THEN REVCHK2 = .;
   IF (REVCHK2A <= -1) THEN REVCHK2A = .;
   IF (EARMARK <= -1) THEN EARMARK = .;
   IF (FEESCALE <= -1) THEN FEESCALE = .;
   IF (PAYASST <= -1) THEN PAYASST = .;
   IF (WRITARRA <= -1) THEN WRITARRA = .;
   IF (LICENSED <= -1) THEN LICENSED = .;
   IF (LICENMH <= -1) THEN LICENMH = .;
   IF (LICENPH <= -1) THEN LICENPH = .;
   IF (LICENHOS <= -1) THEN LICENHOS = .;
   IF (JCAHO <= -1) THEN JCAHO = .;
   IF (CARF <= -1) THEN CARF = .;
   IF (NCQA <= -1) THEN NCQA = .;
   IF (COA <= -1) THEN COA = .;
   IF (OTHSTATE <= -1) THEN OTHSTATE = .;
   IF (ADMINLNK <= -1) THEN ADMINLNK = .;
   IF (OTHFAC2 <= -1) THEN OTHFAC2 = .;
   IF (OTHFAC1 <= -1) THEN OTHFAC1 = .;
   IF (OTHFAC3 <= -1) THEN OTHFAC3 = .;
   IF (TYPE4 <= -1) THEN TYPE4 = .;
   IF (T_CLI1 <= -1) THEN T_CLI1 = .;
   IF (T_CLI2 <= -1) THEN T_CLI2 = .;
   IF (T_CLIHI <= -1) THEN T_CLIHI = .;
   IF (H_AGE1 <= -1) THEN H_AGE1 = .;
   IF (HIMETNUM <= -1) THEN HIMETNUM = .;
   IF (HILAMNUM <= -1) THEN HILAMNUM = .;
   IF (TYPE7 <= -1) THEN TYPE7 = .;
   IF (T_CLI3 <= -1) THEN T_CLI3 = .;
   IF (T_CLI4 <= -1) THEN T_CLI4 = .;
   IF (T_CLIRC <= -1) THEN T_CLIRC = .;
   IF (R_AGE1 <= -1) THEN R_AGE1 = .;
   IF (RCMETNUM <= -1) THEN RCMETNUM = .;
   IF (RCLAMNUM <= -1) THEN RCLAMNUM = .;
   IF (TYPE1 <= -1) THEN TYPE1 = .;
   IF (T_CLI7 <= -1) THEN T_CLI7 = .;
   IF (T_CLIML <= -1) THEN T_CLIML = .;
   IF (T_CLI5 <= -1) THEN T_CLI5 = .;
   IF (T_CLI6 <= -1) THEN T_CLI6 = .;
   IF (T_CLI8 <= -1) THEN T_CLI8 = .;
   IF (T_CLIOP <= -1) THEN T_CLIOP = .;
   IF (O_AGE1 <= -1) THEN O_AGE1 = .;
   IF (OPMETNUM <= -1) THEN OPMETNUM = .;
   IF (OPLAMNUM <= -1) THEN OPLAMNUM = .;
   IF (B_PCT <= -1) THEN B_PCT = .;
   IF (A_PCT <= -1) THEN A_PCT = .;
   IF (D_PCT <= -1) THEN D_PCT = .;
   IF (TOTADMIS <= -1) THEN TOTADMIS = .;
   IF (FACCLI <= -1) THEN FACCLI = .;
   IF (FACNUM <= -1) THEN FACNUM = .;
   IF (ACTHI <= -1) THEN ACTHI = .;
   IF (ACTRES <= -1) THEN ACTRES = .;
   IF (ACTOP <= -1) THEN ACTOP = .;
   IF (TOTADEST <= -1) THEN TOTADEST = .;
   IF (LOC5 <= -1) THEN LOC5 = .;
   IF (INTERNET <= -1) THEN INTERNET = .;
   IF (HASWEB <= -1) THEN HASWEB = .;
   IF (RPTLVL <= -1) THEN RPTLVL = .;
   IF (T_CLI9 <= -1) THEN T_CLI9 = .;
   IF (T_CLIJUV <= -1) THEN T_CLIJUV = .;
   IF (T_CLIMET <= -1) THEN T_CLIMET = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT MODE mode. STFIPS stfips. REGION region.
         DIVISION division. TREATMT treatmt. DETOX detox.
         OWNERSHP ownershp. FEDOWN fedown. LOC15 loc15fff.
         RELIG relig. HOSPITAL hospital. LOCS locs.
         FOCUS focus. HOTYN hotyn. SRVC1 srvc1fff.
         SRVC2 srvc2fff. SRVC4 srvc4fff. SRVC5 srvc5fff.
         SRVC6 srvc6fff. SRVC8 srvc8fff. SRVC27 srvc27ff.
         SRVC70 srvc70ff. SRVC71 srvc71ff. SRVC10 srvc10ff.
         SRVC11 srvc11ff. SRVC13 srvc13ff. SRVC14 srvc14ff.
         SRVC15 srvc15ff. SRVC16 srvc16ff. SRVC36 srvc36ff.
         SRVC37 srvc37ff. SRVC38 srvc38ff. SRVC39 srvc39ff.
         SRVC40 srvc40ff. SRVC49 srvc49ff. SRVC50 srvc50ff.
         SRVC52 srvc52ff. SRVC24 srvc24ff. SRVC55 srvc55ff.
         SRVC59 srvc59ff. SRVC48 srvc48ff. OTP otp.
         OTPTYPE otptype. OTPALL otpall. DUI_DWI dui_dwi.
         ONLYDUI onlydui. SRVC61 srvc61ff. SIGNLANG signlang.
         LANG lang. LANG1 lang1fff. LANG2 lang2fff.
         LANG3 lang3fff. LANG4 lang4fff. LANG5 lang5fff.
         LANG6 lang6fff. LANG7 lang7fff. LANG8 lang8fff.
         LANG9 lang9fff. LANG10 lang10ff. LANG11 lang11ff.
         LANG12 lang12ff. LANG13 lang13ff. LANG14 lang14ff.
         LANG15 lang15ff. LANG16 lang16ff. LANG17 lang17ff.
         LANG18 lang18ff. SRVC30 srvc30ff. SRVC31 srvc31ff.
         SRVC32 srvc32ff. SRVC62 srvc62ff. SRVC63 srvc63ff.
         SRVC33 srvc33ff. SRVC34 srvc34ff. SRVC64 srvc64ff.
         SRVC35 srvc35ff. CTYPE4 ctype4ff. CTYPEHI1 ctypehif.
         CTYPEHI2 ctypeh0f. HOSPBED hospbed. CTYPE7 ctype7ff.
         CTYPERC1 ctypercf. CTYPERC2 ctyper0f. RESBED resbed.
         CTYPE1 ctype1ff. CTYPE6 ctype6ff. CTYPEML ctypeml.
         CTYPE3 ctype3ff. CTYPE2 ctype2ff. CTYPEOP ctypeop.
         REVCHK1 revchk1f. REVCHK8 revchk8f. REVCHK5 revchk5f.
         REVCHK10 revchk0f. REVCHK15 revchk2f. REVCHK2 revchk3f.
         REVCHK2A revchk2a. EARMARK earmark. FEESCALE feescale.
         PAYASST payasst. WRITARRA writarra. LICENSED licensed.
         LICENMH licenmh. LICENPH licenph. LICENHOS licenhos.
         JCAHO jcaho. CARF carf. NCQA ncqa.
         COA coa. OTHSTATE othstate. ADMINLNK adminlnk.
         OTHFAC2 othfac2f. OTHFAC1 othfac1f. OTHFAC3 othfac3f.
         TYPE4 type4fff. T_CLI1 t_cli1ff. T_CLI2 t_cli2ff.
         T_CLIHI t_clihi. H_AGE1 h_age1ff. HIMETNUM himetnum.
         HILAMNUM hilamnum. TYPE7 type7fff. T_CLI3 t_cli3ff.
         T_CLI4 t_cli4ff. T_CLIRC t_clirc. R_AGE1 r_age1ff.
         RCMETNUM rcmetnum. RCLAMNUM rclamnum. TYPE1 type1fff.
         T_CLI7 t_cli7ff. T_CLIML t_climl. T_CLI5 t_cli5ff.
         T_CLI6 t_cli6ff. T_CLI8 t_cli8ff. T_CLIOP t_cliop.
         O_AGE1 o_age1ff. OPMETNUM opmetnum. OPLAMNUM oplamnum.
         B_PCT b_pct. A_PCT a_pct. D_PCT d_pct.
         TOTADMIS totadmis. FACCLI faccli. FACNUM facnum.
         ACTHI acthi. ACTRES actres. ACTOP actop.
         TOTADEST totadest. LOC5 loc5ffff. INTERNET internet.
         HASWEB hasweb. RPTLVL rptlvl. T_CLI9 t_cli9ff.
         T_CLIJUV t_clijuv. T_CLIMET t_climet. OWNRSPFL ownrspfl.
         FEDOWNFL fedownfl. OTPFL otpfl. CTYPEHFL ctypehfl.
         CTYPERFL ctyperfl. CTYPEOFL ctypeofl. CTYPEMLF ctypemlf.
         LINKSFL linksfl. T_CLI1FL t_cli1fl. T_CLI2FL t_cli2fl.
         T_CLIHIF t_clihif. HIMTNMFL himtnmfl. HILMNMFL hilmnmfl.
         T_CLI3FL t_cli3fl. T_CLI4FL t_cli4fl. T_CLIRCF t_clircf.
         RCMTNMFL rcmtnmfl. RCLMNMFL rclmnmfl. T_CLI7FL t_cli7fl.
         T_CLIMLF t_climlf. T_CLI5FL t_cli5fl. T_CLI6FL t_cli6fl.
         T_CLI8FL t_cli8fl. T_CLIOPF t_cliopf. OPMTNMFL opmtnmfl.
         OPLMNMFL oplmnmfl. B_PCTFL b_pctfl. A_PCTFL a_pctfl.
         D_PCTFL d_pctfl. TOTADMFL totadmfl.  ;
*/

RUN ;
